@@ -109,7 +109,7 @@ def ifc(filename="SIRIFC", ifc_=None):
         if ifc_.nish[isym]:
             Ci = ifc_.cmo.subblock[isym]
             Cocci = Ci[:, : ifc_.nish[isym]]
-            Di.subblock[isym] = 2 * Cocci * Cocci.T
+            Di.subblock[isym] = 2 * Cocci @ Cocci.T
     Di = Di.unblock()
     if ifc_.nasht:
         cmoa = blocked.BlockDiagonalMatrix(ifc_.nbas, ifc_.nash)
@@ -119,7 +119,7 @@ def ifc(filename="SIRIFC", ifc_=None):
                 nocci = ifc_.nish[isym] + ifc_.nash[isym]
                 cmoa.subblock[isym] = ifc_.cmo.subblock[isym][:, nishi:nocci]
         cmoa = cmoa.unblock()
-        Dv = cmoa * ifc_.dv.unpack() * cmoa.T
+        Dv = cmoa @ ifc_.dv.unpack() @ cmoa.T
     else:
         Dv = full.matrix((ifc_.nbast, ifc_.nbast))
     return Di, Dv
