@@ -47,7 +47,7 @@ def read(*args, **kwargs):
                     rec.read(16, "c")
                     cfreq, bfreq = rec.read(2, "d")
                 if bfreq in bfreqs and cfreq in cfreqs:
-                    _rec = rspvec.next()
+                    _rec = next(rspvec)
                     kzyvar = len(_rec) // 8
                     buffer_ = rspvec.readbuf(kzyvar, "d")
                     vecs[(lab, bfreq, cfreq)] = \
@@ -89,7 +89,7 @@ def readall(property_label, propfile="RSPVEC"):
     while _rspvec.find(property_label) is not None:
         _rspvec.rec.read(16, "c")
         vfreq = _rspvec.rec.read(1, "d")[0]
-        _rec = _rspvec.next()
+        _rec = next(_rspvec)
         kzyvar = len(_rec) // 8
         buffer_ = _rspvec.readbuf(kzyvar, "d")
         mat = numpy.array(buffer_).view(full.matrix)
